@@ -3,35 +3,8 @@
 # Univention AD Connector
 #  this file defines the mapping between AD and UCS
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2004-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
 import importlib.util
@@ -84,7 +57,7 @@ def ignore_filter_from_attr(attribute, ucr_key, default=''):
 
 def get_mapping(configbasename='connector'):
     ad_mapping = create_mapping(configbasename)
-    return load_localmapping(ad_mapping, '/etc/univention/%s/ad/localmapping.py' % configbasename)
+    return load_localmapping(ad_mapping, f'/etc/univention/{configbasename}/ad/localmapping.py')
 
 
 def create_mapping(configbasename='connector'):
@@ -102,17 +75,17 @@ def create_mapping(configbasename='connector'):
                 global_allow_subtree_ucs.append(configRegistry[key])
 
     global_ignore_subtree = [
-        'cn=univention,%(ldap/base)s' % configRegistry,
-        'cn=policies,%(ldap/base)s' % configRegistry,
-        'cn=shares,%(ldap/base)s' % configRegistry,
-        'cn=printers,%(ldap/base)s' % configRegistry,
-        'cn=networks,%(ldap/base)s' % configRegistry,
-        'cn=kerberos,%(ldap/base)s' % configRegistry,
-        'cn=dhcp,%(ldap/base)s' % configRegistry,
-        'cn=dns,%(ldap/base)s' % configRegistry,
-        'cn=mail,%(ldap/base)s' % configRegistry,
-        'cn=samba,%(ldap/base)s' % configRegistry,
-        'cn=nagios,%(ldap/base)s' % configRegistry,
+        'cn=univention,{ldap/base}'.format(**configRegistry),
+        'cn=policies,{ldap/base}'.format(**configRegistry),
+        'cn=shares,{ldap/base}'.format(**configRegistry),
+        'cn=printers,{ldap/base}'.format(**configRegistry),
+        'cn=networks,{ldap/base}'.format(**configRegistry),
+        'cn=kerberos,{ldap/base}'.format(**configRegistry),
+        'cn=dhcp,{ldap/base}'.format(**configRegistry),
+        'cn=dns,{ldap/base}'.format(**configRegistry),
+        'cn=mail,{ldap/base}'.format(**configRegistry),
+        'cn=samba,{ldap/base}'.format(**configRegistry),
+        'cn=nagios,{ldap/base}'.format(**configRegistry),
         connector('cn=System,%%(%s/ad/ldap/base)s') % configRegistry,
         connector('ou=Grp Policy Users,%%(%s/ad/ldap/base)s') % configRegistry,
         connector('cn=Builtin,%%(%s/ad/ldap/base)s') % configRegistry,
@@ -120,7 +93,7 @@ def create_mapping(configbasename='connector'):
         connector('ou=Domain Controllers,%%(%s/ad/ldap/base)s') % configRegistry,
         connector('cn=Program Data,%%(%s/ad/ldap/base)s') % configRegistry,
         connector('cn=Configuration,%%(%s/ad/ldap/base)s') % configRegistry,
-        'cn=opsi,%(ldap/base)s' % configRegistry,
+        'cn=opsi,{ldap/base}'.format(**configRegistry),
         connector('cn=Microsoft Exchange System Objects,%%(%s/ad/ldap/base)s') % configRegistry,
     ]
 
@@ -163,7 +136,7 @@ def create_mapping(configbasename='connector'):
 
     ad_mapping = {
         'user': univention.connector.property(
-            ucs_default_dn='cn=users,%(ldap/base)s' % configRegistry,
+            ucs_default_dn='cn=users,{ldap/base}'.format(**configRegistry),
             con_default_dn=connector('cn=users,%%(%s/ad/ldap/base)s') % configRegistry,
             ucs_module='users/user',
             # read, write, sync, none
@@ -335,7 +308,7 @@ def create_mapping(configbasename='connector'):
             },
         ),
         'group': univention.connector.property(
-            ucs_default_dn='cn=groups,%(ldap/base)s' % configRegistry,
+            ucs_default_dn='cn=groups,{ldap/base}'.format(**configRegistry),
             con_default_dn=connector('cn=Users,%%(%s/ad/ldap/base)s') % configRegistry,
             ucs_module='groups/group',
             sync_mode=configRegistry.get(connector('%s/ad/mapping/group/syncmode'), configRegistry.get(connector('%s/ad/mapping/syncmode'))),
@@ -417,7 +390,7 @@ def create_mapping(configbasename='connector'):
             },
         ),
         'windowscomputer': univention.connector.property(
-            ucs_default_dn='cn=computers,%(ldap/base)s' % configRegistry,
+            ucs_default_dn='cn=computers,{ldap/base}'.format(**configRegistry),
             con_default_dn=connector('cn=computers,%%(%s/ad/ldap/base)s') % configRegistry,
             ucs_module='computers/windows',
             ucs_module_others=['computers/memberserver', 'computers/linux', 'computers/ubuntu', 'computers/macos'],
@@ -523,7 +496,7 @@ def create_mapping(configbasename='connector'):
     }
 
     # allow filter
-    for obj_type in ad_mapping.keys():
+    for obj_type in ad_mapping.keys():  # noqa: PLC0206
         allow_filter = configRegistry.get(connector(f'%s/ad/mapping/{obj_type}/allowfilter'), '')
         if allow_filter:
             if not allow_filter.startswith('('):
