@@ -3,41 +3,15 @@
 # Univention AD Connector
 #  control the password sync communication with the ad password service
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2004-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import binascii
 import hashlib
 import struct
 import time
 import traceback
+from logging import getLogger
 from struct import pack
 
 import heimdal
@@ -51,7 +25,10 @@ from samba.dcerpc import drsblobs, drsuapi, lsa, misc, security
 from samba.ndr import ndr_unpack
 
 import univention.connector.ad
-import univention.debug2 as ud
+from univention.logging import Structured
+
+
+log = Structured(getLogger("LDAP").getChild(__name__))
 
 
 def nt_password_to_arcfour_hmac_md5(nt_password):
@@ -171,7 +148,7 @@ def calculate_krb5keys(supplementalCredentialsblob):
         assert krb5_old.version == 3
         for k in krb5_old.ctr.keys:
             if k.keytype not in keytypes:
-                ud.debug(ud.LDAP, ud.INFO, "calculate_krb5key: ctr3.key.keytype: %s" % k.keytype)
+                log.debug("calculate_krb5key: ctr3.key.keytype: %s", k.keytype)
                 try:
                     key = heimdal.keyblock_raw(context, k.keytype, k.value)
                     krb5SaltObject = heimdal.salt_raw(context, krb5_old.ctr.salt.string)
@@ -179,10 +156,10 @@ def calculate_krb5keys(supplementalCredentialsblob):
                     keytypes.append(k.keytype)
                 except Exception:
                     if k.keytype == 4294967156:  # in all known cases W2k8 AD uses keytype 4294967156 (=-140L) for this
-                        ud.debug(ud.LDAP, ud.INFO, "calculate_krb5key: ignoring unknown key with special keytype %s in %s" % (k.keytype, pkg.name))
+                        log.debug("calculate_krb5key: ignoring unknown key with special keytype %s in %s", k.keytype, pkg.name)
                     else:
-                        ud.debug(ud.LDAP, ud.ERROR, "calculate_krb5key: krb5Key with keytype %s could not be parsed in %s. Ignoring this keytype." % (k.keytype, pkg.name))
-                        ud.debug(ud.LDAP, ud.ERROR, traceback.format_exc())
+                        log.error("calculate_krb5key: krb5Key with keytype %s could not be parsed in %s. Ignoring this keytype.", k.keytype, pkg.name)
+                        log.error(traceback.format_exc())
 
     krb5_new_hex = None
 
@@ -199,7 +176,7 @@ def calculate_krb5keys(supplementalCredentialsblob):
 
         for k in krb.ctr.keys:
             if k.keytype not in keytypes:
-                ud.debug(ud.LDAP, ud.INFO, "calculate_krb5key: ctr4.key.keytype: %s" % k.keytype)
+                log.debug("calculate_krb5key: ctr4.key.keytype: %s", k.keytype)
                 try:
                     key = heimdal.keyblock_raw(context, k.keytype, k.value)
                     krb5SaltObject = heimdal.salt_raw(context, krb.ctr.salt.string)
@@ -207,10 +184,10 @@ def calculate_krb5keys(supplementalCredentialsblob):
                     keytypes.append(k.keytype)
                 except Exception:
                     if k.keytype == 4294967156:  # in all known cases W2k8 AD uses keytype 4294967156 (=-140L) for this
-                        ud.debug(ud.LDAP, ud.INFO, "calculate_krb5key: ignoring unknown key with special keytype %s in %s" % (k.keytype, pkg.name))
+                        log.debug("calculate_krb5key: ignoring unknown key with special keytype %s in %s", k.keytype, pkg.name)
                     else:
-                        ud.debug(ud.LDAP, ud.ERROR, "calculate_krb5key: krb5Key with keytype %s could not be parsed in %s. Ignoring this keytype." % (k.keytype, pkg.name))
-                        ud.debug(ud.LDAP, ud.ERROR, traceback.format_exc())
+                        log.error("calculate_krb5key: krb5Key with keytype %s could not be parsed in %s. Ignoring this keytype.", k.keytype, pkg.name)
+                        log.error(traceback.format_exc())
     return keys
 
 
@@ -271,13 +248,13 @@ def decrypt_supplementalCredentials(connector, spl_crypt):
     (crc32_v) = struct.unpack("<L", plain_buffer[0:4])
     attr_val = plain_buffer[4:]
     crc32_c = binascii.crc32(attr_val) & 0xffffffff
-    assert int(crc32_v[0]) == int(crc32_c), "CRC32 0x%08X != 0x%08X" % (crc32_v[0], crc32_c)
+    assert int(crc32_v[0]) == int(crc32_c), f"CRC32 0x{crc32_v[0]:08X} != 0x{crc32_c:08X}"
 
     return ndr_unpack(drsblobs.supplementalCredentialsBlob, attr_val)
 
 
 def get_password_from_ad(connector, user_dn, reconnect=False):
-    ud.debug(ud.LDAP, ud.INFO, "get_password_from_ad: Read password from AD: %s" % user_dn)
+    log.debug("get_password_from_ad: Read password from AD: %s", user_dn)
     nt_hash = None
     nt_hashes = []
 
@@ -316,15 +293,15 @@ def get_password_from_ad(connector, user_dn, reconnect=False):
                 if i.value_ctr.values:
                     for j in i.value_ctr.values:
                         unicode_blob = j.blob
-                        ud.debug(ud.LDAP, ud.INFO, "get_password_from_ad: Found unicodePwd blob")
+                        log.debug("get_password_from_ad: Found unicodePwd blob")
             if i.attid == drsuapi.DRSUAPI_ATTID_ntPwdHistory and i.value_ctr.values:
                 for j in i.value_ctr.values:
-                    ud.debug(ud.LDAP, ud.INFO, "get_password_from_ad: Found ntPwdHistory blob")
+                    log.debug("get_password_from_ad: Found ntPwdHistory blob")
                     history_blob = j.blob
-            if i.attid == drsuapi.DRSUAPI_ATTID_supplementalCredentials and connector.configRegistry.is_true('%s/ad/mapping/user/password/kerberos/enabled' % connector.CONFIGBASENAME, False):
+            if i.attid == drsuapi.DRSUAPI_ATTID_supplementalCredentials and connector.configRegistry.is_true(f'{connector.CONFIGBASENAME}/ad/mapping/user/password/kerberos/enabled', False):
                 if i.value_ctr.values:
                     for j in i.value_ctr.values:
-                        ud.debug(ud.LDAP, ud.INFO, "get_password_from_ad: Found supplementalCredentials blob")
+                        log.debug("get_password_from_ad: Found supplementalCredentials blob")
                         spl = decrypt_supplementalCredentials(connector, j.blob)
                         keys = calculate_krb5keys(spl)
 
@@ -337,7 +314,7 @@ def get_password_from_ad(connector, user_dn, reconnect=False):
         if ctr.more_data == 0:
             break
 
-    ud.debug(ud.LDAP, ud.INFO, "get_password_from_ad: AD Hash: %s" % nt_hash)
+    log.debug("get_password_from_ad: AD Hash: %s", nt_hash)
 
     return nt_hash, keys, nt_hashes
 
@@ -346,70 +323,70 @@ def password_sync_ucs(connector, key, object):
     # externes Programm zum Überptragen des Hash aufrufen
     # per ldapmodify pwdlastset auf -1 setzen
 
-    ud.debug(ud.LDAP, ud.INFO, "Object DN=%r" % (object['dn'],))
+    log.debug("Object DN=%r", object['dn'])
 
     ucs_object = connector._object_mapping(key, object, 'con')
 
-    ud.debug(ud.LDAP, ud.INFO, "   UCS DN = %r" % (ucs_object['dn'],))
+    log.debug("   UCS DN = %r", ucs_object['dn'])
 
     try:
         res = connector.lo.lo.search(base=ucs_object['dn'], scope='base', attr=['sambaLMPassword', 'sambaNTPassword', 'sambaPwdLastSet'])
     except ldap.NO_SUCH_OBJECT:
-        ud.debug(ud.LDAP, ud.PROCESS, "password_sync_ucs: The UCS object (%s) was not found. The object was removed." % ucs_object['dn'])
+        log.process("password_sync_ucs_to_ad: The UCS object (%s) was not found. The object was removed.", ucs_object['dn'])
         return
 
     sambaPwdLastSet = None
     if 'sambaPwdLastSet' in res[0][1]:
         sambaPwdLastSet = int(res[0][1]['sambaPwdLastSet'][0])
-    ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: sambaPwdLastSet: %s" % sambaPwdLastSet)
+    log.debug("password_sync_ucs: sambaPwdLastSet: %s", sambaPwdLastSet)
 
     pwd = None
     if 'sambaNTPassword' in res[0][1]:
         pwd = res[0][1]['sambaNTPassword'][0]
     else:
-        ud.debug(ud.LDAP, ud.WARN, "password_sync_ucs: Failed to get NT Hash from UCS")
+        log.warning("password_sync_ucs: Failed to get NT Hash from UCS")
 
     res = connector.lo_ad.lo.search_s(object['dn'], ldap.SCOPE_BASE, '(objectClass=*)', ['pwdLastSet', 'objectSid'])
     pwdLastSet = None
     if 'pwdLastSet' in res[0][1]:
         pwdLastSet = int(res[0][1]['pwdLastSet'][0])
-    ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: pwdLastSet from AD : %s" % pwdLastSet)
+    log.debug("password_sync_ucs: pwdLastSet from AD : %s", pwdLastSet)
     if 'objectSid' in res[0][1]:
         str(univention.connector.ad.decode_sid(res[0][1]['objectSid'][0]).split('-')[-1])
 
     # Only sync passwords from UCS to AD when the password timestamp in UCS is newer
-    if connector.configRegistry.is_true('%s/ad/password/timestamp/check' % connector.CONFIGBASENAME, False):
+    if connector.configRegistry.is_true(f'{connector.CONFIGBASENAME}/ad/password/timestamp/check', False):
         ad_password_last_set = 0
         # If sambaPwdLast was set to 1 the password must be changed on next login. In this
         # case the timestamp is ignored and the password will be synced. This behavior can
         # be disabled by setting connector/ad/password/timestamp/syncreset/ucs to false. This
         # might be necessary if the connector is configured in read mode and the password will be
         # synced in two ways: Bug #22653
-        if sambaPwdLastSet > 1 or (sambaPwdLastSet <= 2 and connector.configRegistry.is_false('%s/ad/password/timestamp/syncreset/ucs' % connector.CONFIGBASENAME, False)):
+        if sambaPwdLastSet > 1 or (sambaPwdLastSet <= 2 and connector.configRegistry.is_false(f'{connector.CONFIGBASENAME}/ad/password/timestamp/syncreset/ucs', False)):
             ad_password_last_set = univention.connector.ad.ad2samba_time(pwdLastSet)
             if sambaPwdLastSet and int(ad_password_last_set) >= int(sambaPwdLastSet):
                 # skip
-                ud.debug(ud.LDAP, ud.PROCESS, "password_sync: Don't sync the password from UCS to AD because the AD password equal or is newer.")
-                ud.debug(ud.LDAP, ud.INFO, "password_sync:  AD pwdlastset: %s (original (%s))" % (ad_password_last_set, pwdLastSet))
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: UCS pwdlastset: %s" % (sambaPwdLastSet))
+                log.process("password_sync: Don't sync the password from UCS to AD because the AD password equal or is newer.")
+                log.debug("password_sync:  AD pwdlastset: %s (original (%s))", ad_password_last_set, pwdLastSet)
+                log.debug("password_sync: UCS pwdlastset: %s", sambaPwdLastSet)
                 return
 
-        ud.debug(ud.LDAP, ud.INFO, "password_sync: Sync the passwords from UCS to AD.")
-        ud.debug(ud.LDAP, ud.INFO, "password_sync:  AD pwdlastset: %s (original (%s))" % (ad_password_last_set, pwdLastSet))
-        ud.debug(ud.LDAP, ud.INFO, "password_sync: UCS pwdlastset: %s" % (sambaPwdLastSet))
+        log.debug("password_sync: Sync the passwords from UCS to AD.")
+        log.debug("password_sync:  AD pwdlastset: %s (original (%s))", ad_password_last_set, pwdLastSet)
+        log.debug("password_sync: UCS pwdlastset: %s", sambaPwdLastSet)
 
     pwd_set = False
     try:
         nt_hash, _krb5Key, _ = get_password_from_ad(connector, object['dn'])
     except NTSTATUSError as exc:
-        ud.debug(ud.LDAP, ud.PROCESS, "password_sync_ucs: get_password_from_ad failed with %s, retry with reconnect" % (exc,))
+        log.process("password_sync_ucs: get_password_from_ad failed with %s, retry with reconnect", exc)
         nt_hash, _krb5Key, _ = get_password_from_ad(connector, object['dn'], reconnect=True)
 
     if not nt_hash:
-        ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: No password hash could be read from AD")
+        log.debug("password_sync_ucs: No password hash could be read from AD")
     res = ''
 
-    ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: Hash AD: %s Hash UCS: %s" % (nt_hash, pwd))
+    log.debug("password_sync_ucs: Hash AD: %s Hash UCS: %s", nt_hash, pwd)
     if not pwd or pwd.startswith(b'NO PASSWORD'):
         # There are variations of "NO PASSWORD" in customer environments:
         # 1. "NO PASSWORD*********************" (password_sync_kinit, see below)
@@ -417,31 +394,31 @@ def password_sync_ucs(connector, key, object):
         # 3. "NO PASSWORDXXXXXXX"               (Ticket #2020121821000706)
         # 4. "NO PASSWORDXXXXXXXXXXXXXXXXXXXXX" (/usr/share/univention-heimdal/kerberos_now)
         # see https://forge.univention.org/bugzilla/buglist.cgi?longdesc=NO%20PASSWORD&longdesc_type=casesubstring
-        ud.debug(ud.LDAP, ud.PROCESS, "The sambaNTPassword hash is set to %s. Skip the synchronisation of this hash to AD." % pwd)
+        log.process("The sambaNTPassword hash is set to %s. Skip the synchronisation of this hash to AD.", pwd)
     elif pwd != nt_hash:
-        ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: Hash AD and Hash UCS differ")
+        log.debug("password_sync_ucs: Hash AD and Hash UCS differ")
         pwd_set = True
 
         try:
             res = set_password_in_ad(connector, object['attributes']['sAMAccountName'][0], pwd)
         except NTSTATUSError as exc:
-            ud.debug(ud.LDAP, ud.PROCESS, "password_sync: set_password_in_ad failed with %s, retry with reconnect" % (exc,))
+            log.process("password_sync: set_password_in_ad failed with %s, retry with reconnect", exc)
             res = set_password_in_ad(connector, object['attributes']['sAMAccountName'][0], pwd, reconnect=True)
 
     newpwdlastset = "-1"  # if pwd was set in ad we need to set pwdlastset to -1 or it will be 0
     # if sambaPwdMustChange >= 0 and sambaPwdMustChange < time.time():
     # password expired, must be changed on next login
-    #    ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: samba pwd expired, set newpwdLastSet to 0")
+    #    log.debug("password_sync_ucs: samba pwd expired, set newpwdLastSet to 0")
     #    newpwdlastset = "0"
     if sambaPwdLastSet <= 1:
         newpwdlastset = "0"  # User must change his password
     elif pwdLastSet and int(pwdLastSet) > 0 and not pwd_set:
         newpwdlastset = "1"
     if int(newpwdlastset) != 1:
-        ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: pwdlastset in modlist: %s" % newpwdlastset)
+        log.debug("password_sync_ucs: pwdlastset in modlist: %s", newpwdlastset)
         connector.lo_ad.lo.modify_s(object['dn'], [(ldap.MOD_REPLACE, 'pwdlastset', newpwdlastset.encode('ASCII'))])
     else:
-        ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: don't modify pwdlastset")
+        log.debug("password_sync_ucs: don't modify pwdlastset")
 
 
 def password_sync_kinit(connector, key, ucs_object):
@@ -453,7 +430,7 @@ def password_sync_kinit(connector, key, ucs_object):
     ucs_result = connector.lo.search(base=ucs_object['dn'], attr=attr.keys())
 
     modlist = []
-    for attribute in attr.keys():
+    for attribute in attr.keys():  # noqa: PLC0206
         expected_value = attr[attribute]
         if attribute in ucs_result[0][1]:
             userPassword = ucs_result[0][1][attribute][0]
@@ -473,13 +450,13 @@ def password_sync(connector, key, ucs_object):
 
     if connector.isInCreationList(object['dn']):
         connector.removeFromCreationList(object['dn'])
-        ud.debug(ud.LDAP, ud.INFO, "password_sync: Synchronisation of password has been canceled. Object was just created.")
+        log.debug("password_sync: Synchronisation of password has been canceled. Object was just created.")
         return
 
     pwdLastSet = None
     if 'pwdLastSet' in res[0][1]:
         pwdLastSet = int(res[0][1]['pwdLastSet'][0])
-    ud.debug(ud.LDAP, ud.INFO, "password_sync: pwdLastSet from AD: %s (%s)" % (pwdLastSet, res))
+    log.debug("password_sync: pwdLastSet from AD: %s (%s)", pwdLastSet, res)
 
     if 'objectSid' in res[0][1]:
         str(univention.connector.ad.decode_sid(res[0][1]['objectSid'][0]).split('-')[-1])
@@ -489,9 +466,9 @@ def password_sync(connector, key, ucs_object):
     sambaPwdLastSet = None
     if 'sambaPwdLastSet' in ucs_result[0][1]:
         sambaPwdLastSet = ucs_result[0][1]['sambaPwdLastSet'][0]
-    ud.debug(ud.LDAP, ud.INFO, "password_sync: sambaPwdLastSet: %s" % sambaPwdLastSet)
+    log.debug("password_sync: sambaPwdLastSet: %s", sambaPwdLastSet)
 
-    if connector.configRegistry.is_true('%s/ad/password/timestamp/check' % connector.CONFIGBASENAME, False):
+    if connector.configRegistry.is_true(f'{connector.CONFIGBASENAME}/ad/password/timestamp/check', False):
         # Only sync the passwords from AD to UCS when the pwdLastSet timestamps in AD are newer
         ad_password_last_set = 0
 
@@ -500,23 +477,23 @@ def password_sync(connector, key, ucs_object):
         # be disabled by setting connector/ad/password/timestamp/syncreset/ad to false. This
         # might be necessary if the connector is configured in read mode and the password will be
         # synced in two ways: Bug #22653
-        if (pwdLastSet > 1) or (pwdLastSet in [0, 1] and connector.configRegistry.is_false('%s/ad/password/timestamp/syncreset/ad' % connector.CONFIGBASENAME, False)):
+        if (pwdLastSet > 1) or (pwdLastSet in [0, 1] and connector.configRegistry.is_false(f'{connector.CONFIGBASENAME}/ad/password/timestamp/syncreset/ad', False)):
             ad_password_last_set = univention.connector.ad.ad2samba_time(pwdLastSet)
             if sambaPwdLastSet and int(sambaPwdLastSet) >= int(ad_password_last_set) and int(sambaPwdLastSet) != 1:
                 # skip
-                ud.debug(ud.LDAP, ud.PROCESS, "password_sync: Don't sync the passwords from AD to UCS because the UCS password is equal or newer.")
-                ud.debug(ud.LDAP, ud.INFO, "password_sync:  AD pwdlastset: %s (original (%s))" % (ad_password_last_set, pwdLastSet))
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: UCS pwdlastset: %s" % (sambaPwdLastSet))
+                log.process("password_sync: Don't sync the passwords from AD to UCS because the UCS password is equal or newer.")
+                log.debug("password_sync:  AD pwdlastset: %s (original (%s))", ad_password_last_set, pwdLastSet)
+                log.debug("password_sync: UCS pwdlastset: %s", sambaPwdLastSet)
                 return
 
-        ud.debug(ud.LDAP, ud.INFO, "password_sync: Sync the passwords from AD to UCS.")
-        ud.debug(ud.LDAP, ud.INFO, "password_sync:  AD pwdlastset: %s (original (%s))" % (ad_password_last_set, pwdLastSet))
-        ud.debug(ud.LDAP, ud.INFO, "password_sync: UCS pwdlastset: %s" % (sambaPwdLastSet))
+        log.debug("password_sync: Sync the passwords from AD to UCS.")
+        log.debug("password_sync:  AD pwdlastset: %s (original (%s))", ad_password_last_set, pwdLastSet)
+        log.debug("password_sync: UCS pwdlastset: %s", sambaPwdLastSet)
 
     try:
         nt_hash, krb5Key, nt_history = get_password_from_ad(connector, object['dn'])
     except Exception as exc:
-        ud.debug(ud.LDAP, ud.PROCESS, "password_sync: get_password_from_ad failed with %s, retry with reconnect" % (exc,))
+        log.process("password_sync: get_password_from_ad failed with %s, retry with reconnect", exc)
         nt_hash, krb5Key, nt_history = get_password_from_ad(connector, object['dn'], reconnect=True)
 
     old_krb5end = ucs_result[0][1].get('krb5PasswordEnd', [None])[0]
@@ -540,7 +517,7 @@ def password_sync(connector, key, ucs_object):
 
         if ntPwd.upper() != ntPwd_ucs.upper():
             if ntPwd in [b'00000000000000000000000000000000', b'NO PASSWORD*********************']:
-                ud.debug(ud.LDAP, ud.WARN, "password_sync: AD connector password daemon returned 0 for the nt hash. Please check the AD settings.")
+                log.warning("password_sync: AD connector password daemon returned 0 for the nt hash. Please check the AD settings.")
             else:
                 pwd_changed = True
                 modlist.append(('sambaNTPassword', ntPwd_ucs, ntPwd.upper()))
@@ -568,13 +545,13 @@ def password_sync(connector, key, ucs_object):
             else:
                 ad_object = connector.lo_ad.get(connector.lo_ad.base, attr=['pwdHistoryLength'])
                 ad_pwhistory_length = int(ad_object.get('pwdHistoryLength', [0])[0].decode('UTF-8'))
-            ud.debug(ud.LDAP, ud.INFO, "password_sync:  UCS pwhistoryPolicylength (%s)  AD pwhistoryPolicylength (%s)." % (pwhistory_length, ad_pwhistory_length))
+            log.debug("password_sync:  UCS pwhistoryPolicylength (%s)  AD pwhistoryPolicylength (%s).", pwhistory_length, ad_pwhistory_length)
 
             if pwhistory_length:
                 pwhistory_new = None
 
                 if pwhistory_length != ad_pwhistory_length:
-                    ud.debug(ud.LDAP, ud.WARN, "password_sync: Mismatch between UCS pwhistoryPolicy (%s) and AD pwhistoryPolicy (%s). Using the larger one" % (pwhistory_length, ad_pwhistory_length))
+                    log.warning("password_sync: Mismatch between UCS pwhistoryPolicy (%s) and AD pwhistoryPolicy (%s). Using the larger one", pwhistory_length, ad_pwhistory_length)
                 pwhistory_length = max(pwhistory_length, ad_pwhistory_length)
 
                 pwhistory_list = pwhistory_ucs.decode('ASCII').strip().split(" ")
@@ -591,13 +568,13 @@ def password_sync(connector, key, ucs_object):
                     pwhistory_new = univention.admin.password.get_password_history('{NT}$' + ntPwd.decode('ASCII'), pwhistory_ucs.decode('ASCII'), pwhistory_length).encode('ASCII')
 
                 modlist.append(('pwhistory', pwhistory_ucs, pwhistory_new))
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: Updating pwhistory.")
+                log.debug("password_sync: Updating pwhistory.")
 
             # update shadowLastChange
             new_shadowLastChange = str(int(time.time()) // 3600 // 24).encode('ASCII')
             if pwdLastSet != 0:
                 modlist.append(('shadowLastChange', old_shadowLastChange, new_shadowLastChange))
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: update shadowLastChange to %s for %s" % (new_shadowLastChange, ucs_object['dn']))
+                log.debug("password_sync: update shadowLastChange to %s for %s", new_shadowLastChange, ucs_object['dn'])
 
             # get pw policy
             new_shadowMax = None
@@ -605,7 +582,7 @@ def password_sync(connector, key, ucs_object):
             policies = connector.lo.getPolicies(ucs_object['dn'])
             policy = policies.get('univentionPolicyPWHistory', {}).get('univentionPWExpiryInterval')
             if policy:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: password expiry for %s is %s" % (ucs_object['dn'], policy))
+                log.debug("password_sync: password expiry for %s is %s", ucs_object['dn'], policy)
                 policy_value = policy.get('value', [None])[0]
                 if policy_value:
                     new_shadowMax = '' if int(policy_value) == 0 else str(int(policy_value) - 1).encode('ASCII')
@@ -614,13 +591,13 @@ def password_sync(connector, key, ucs_object):
             # update shadowMax (set to value of univentionPWExpiryInterval, otherwise delete) and
             # krb5PasswordEnd (set to today + univentionPWExpiryInterval, otherwise delete)
             if (old_shadowMax or new_shadowMax) and (pwdLastSet != 0):
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: update shadowMax to %s for %s" % (new_shadowMax, ucs_object['dn']))
+                log.debug("password_sync: update shadowMax to %s for %s", new_shadowMax, ucs_object['dn'])
                 modlist.append(('shadowMax', old_shadowMax, new_shadowMax))
             if (old_krb5end or new_krb5end) and (pwdLastSet != 0):
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: update krb5PasswordEnd to %s for %s" % (new_krb5end, ucs_object['dn']))
+                log.debug("password_sync: update krb5PasswordEnd to %s for %s", new_krb5end, ucs_object['dn'])
                 modlist.append(('krb5PasswordEnd', old_krb5end, new_krb5end))
     else:
-        ud.debug(ud.LDAP, ud.ERROR, "password_sync: sync failed, no result from AD")
+        log.error("password_sync: sync failed, no result from AD")
 
     # update sambaPwdLastSet
     if pwdLastSet or pwdLastSet == 0:
@@ -628,32 +605,32 @@ def password_sync(connector, key, ucs_object):
         if sambaPwdLastSet:
             if sambaPwdLastSet != newSambaPwdLastSet:
                 modlist.append(('sambaPwdLastSet', sambaPwdLastSet, newSambaPwdLastSet))
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: sambaPwdLastSet in modlist (replace): %s" % newSambaPwdLastSet)
+                log.debug("password_sync: sambaPwdLastSet in modlist (replace): %s", newSambaPwdLastSet)
         else:
             modlist.append(('sambaPwdLastSet', b'', newSambaPwdLastSet))
-            ud.debug(ud.LDAP, ud.INFO, "password_sync: sambaPwdLastSet in modlist (set): %s" % newSambaPwdLastSet)
+            log.debug("password_sync: sambaPwdLastSet in modlist (set): %s", newSambaPwdLastSet)
         if pwdLastSet == 0:
             expiry = int(time.time())
             new_krb5end = time.strftime("%Y%m%d000000Z", time.gmtime(expiry)).encode('ASCII')
             if old_krb5end:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: krb5PasswordEnd in modlist (replace): %s" % new_krb5end)
+                log.debug("password_sync: krb5PasswordEnd in modlist (replace): %s", new_krb5end)
                 modlist.append(('krb5PasswordEnd', old_krb5end, new_krb5end))
             else:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: krb5PasswordEnd in modlist (set): %s" % new_krb5end)
+                log.debug("password_sync: krb5PasswordEnd in modlist (set): %s", new_krb5end)
                 modlist.append(('krb5PasswordEnd', b'', new_krb5end))
             if old_shadowMax:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowMax in modlist (replace): 0")
+                log.debug("password_sync: shadowMax in modlist (replace): 0")
                 modlist.append(('shadowMax', old_shadowMax, b'0'))
             else:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowMax in modlist (set): 0")
+                log.debug("password_sync: shadowMax in modlist (set): 0")
                 modlist.append(('shadowMax', b'', b'0'))
-            two_days_ago = int(time.time()) - (86400 * 2)  # FIXME -1day should be enough
+            two_days_ago = int(time.time()) - (86400 * 2)  # FIXME: -1day should be enough
             new_shadowLastChange = str(two_days_ago // 3600 // 24).encode('ASCII')
             if old_shadowLastChange:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowLastChange in modlist (replace): %s" % new_shadowLastChange)
+                log.debug("password_sync: shadowLastChange in modlist (replace): %s", new_shadowLastChange)
                 modlist.append(('shadowLastChange', old_shadowLastChange, new_shadowLastChange))
             else:
-                ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowMax in modlist (set): %s" % new_shadowLastChange)
+                log.debug("password_sync: shadowMax in modlist (set): %s", new_shadowLastChange)
                 modlist.append(('shadowLastChange', b'', new_shadowLastChange))
 
     if len(modlist) > 0:
