@@ -3,41 +3,18 @@
 # Univention AD Connector
 #  ad cache
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2014-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
 import base64
 import sqlite3
+from logging import getLogger
 
-import univention.debug2 as ud
+from univention.logging import Structured
+
+
+log = Structured(getLogger("LDAP").getChild(__name__))
 
 
 def _encode_base64(val):
@@ -149,21 +126,21 @@ class ADCache:
                 cur = self._dbcon.cursor()
                 for sql_command in sql_commands:
                     if isinstance(sql_command, tuple):
-                        ud.debug(ud.LDAP, ud.ALL, "ADCache: Execute SQL command: '%s', '%s'" % (sql_command[0], sql_command[1]))
+                        log.trace("ADCache: Execute SQL command: '%s', '%s'", sql_command[0], sql_command[1])
                         cur.execute(sql_command[0], sql_command[1])
                     else:
-                        ud.debug(ud.LDAP, ud.ALL, "ADCache: Execute SQL command: '%s'" % sql_command)
+                        log.trace("ADCache: Execute SQL command: '%s'", sql_command)
                         cur.execute(sql_command)
                 self._dbcon.commit()
                 if fetch_result:
                     rows = cur.fetchall()
                 cur.close()
                 if fetch_result:
-                    ud.debug(ud.LDAP, ud.ALL, "ADCache: Return SQL result: '%s'" % rows)
+                    log.trace("ADCache: Return SQL result: '%s'", rows)
                     return rows
                 return None
             except sqlite3.Error as exp:
-                ud.debug(ud.LDAP, ud.WARN, "ADCache: sqlite: %s. SQL command was: %s" % (exp, sql_commands))
+                log.warning("ADCache: sqlite: %s. SQL command was: %s", exp, sql_commands)
                 if self._dbcon:
                     self._dbcon.close()
                 self._dbcon = sqlite3.connect(self.filename)
@@ -313,7 +290,7 @@ if __name__ == '__main__':
     entry_old = adcache.get_entry(guid)
     diff_entry = adcache.diff_entry(entry_old, entry)
     if diff_entry.get('changed') or diff_entry.get('removed') or diff_entry.get('added'):
-        raise Exception('Test 1 failed: %s' % diff_entry)
+        raise Exception(f'Test 1 failed: {diff_entry}')
     print('.', end=' ')
 
     entry['attr3'] = [b'val2']
@@ -321,14 +298,14 @@ if __name__ == '__main__':
 
     diff_entry = adcache.diff_entry(entry_old, entry)
     if diff_entry.get('changed') != {'attr2'} or diff_entry.get('removed') or diff_entry.get('added') != {'attr3'}:
-        raise Exception('Test 2 failed: %s' % diff_entry)
+        raise Exception(f'Test 2 failed: {diff_entry}')
     print('.', end=' ')
 
     adcache.add_entry(guid, entry)
     entry_old = adcache.get_entry(guid)
     diff_entry = adcache.diff_entry(entry_old, entry)
     if diff_entry.get('changed') or diff_entry.get('removed') or diff_entry.get('added'):
-        raise Exception('Test 3 failed: %s' % diff_entry)
+        raise Exception(f'Test 3 failed: {diff_entry}')
     print('.', end=' ')
 
     print(' done')
