@@ -3,42 +3,14 @@
 # Univention Management Console
 #  module: AD connector
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2011-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2011-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import functools
 import os.path
 import re
 import subprocess
 import time
-import traceback
 from contextlib import contextmanager
 
 import ldap.dn
@@ -91,7 +63,7 @@ def test_connection():
     rdn = explode_rdn(base)[0]
     p1, _stdout, stderr = adsearch(rdn)
     if stderr:
-        MODULE.warn(stderr)
+        MODULE.warning(stderr)
     if p1.returncode != 0:
         raise ADNotAvailable()
     return True
@@ -112,7 +84,7 @@ def guess_ad_domain_language():
     '''
     _p1, stdout, stderr = adsearch('sAMAccountName=Domänen-Admins')
     if stderr:
-        MODULE.warn('adsearch "sAMAccountName=Domänen-Admins" stderr: %s' % stderr)
+        MODULE.warning('adsearch "sAMAccountName=Domänen-Admins" stderr: %s', stderr)
     for line in stdout.split('\n'):
         line = line.lower().strip()
         if line == 'samaccountname: domänen-admins':
@@ -126,9 +98,9 @@ def get_ad_binddn_from_name(base, server, username, password):
     creds.guess(lp)
     creds.set_username(username)
     creds.set_password(password)
-    binddn = 'cn=%s,cn=users,%s' % (ldap.dn.escape_dn_chars(username), base)
+    binddn = f'cn={ldap.dn.escape_dn_chars(username)},cn=users,{base}'
     try:
-        samdb = SamDB(url='ldap://%s' % server, session_info=system_session(), credentials=creds, lp=lp)
+        samdb = SamDB(url=f'ldap://{server}', session_info=system_session(), credentials=creds, lp=lp)
         res = samdb.search(
             base,
             scope=ldb.SCOPE_SUBTREE,
@@ -137,7 +109,7 @@ def get_ad_binddn_from_name(base, server, username, password):
         if res.count == 1:
             binddn = res.msgs[0].get('dn', idx=0).extended_str()
     except ldb.LdbError as ex:
-        MODULE.warn('get_dn_from_name() could not get binddn for user %s: %s' % (username, ex))
+        MODULE.warning('get_dn_from_name() could not get binddn for user %s: %s', username, ex)
     return binddn
 
 
@@ -224,8 +196,8 @@ class Instance(Base, ProgressMixin):
             if val:
                 if isinstance(val, bool):
                     val = 'yes' if val else 'no'
-                MODULE.info('Setting %s=%s' % (ucrkey, val))
-                univention.config_registry.handler_set(['%s=%s' % (ucrkey, val)])
+                MODULE.info('Setting %s=%s', ucrkey, val)
+                univention.config_registry.handler_set([f'{ucrkey}={val}'])
 
         ucr.load()
         if ucr.get('connector/ad/ldap/ldaps'):
@@ -242,46 +214,46 @@ class Instance(Base, ProgressMixin):
                     fd.write(request.options.get('LDAP_Password'))
                 os.chmod(fn, 0o600)
                 os.chown(fn, 0, 0)
-                univention.config_registry.handler_set(['connector/ad/ldap/bindpw=%s' % fn])
+                univention.config_registry.handler_set([f'connector/ad/ldap/bindpw={fn}'])
             except Exception as e:
-                MODULE.info('Saving bind password failed (filename=%(fn)s ; exception=%(exception)s)' % {'fn': fn, 'exception': str(e.__class__)})
+                MODULE.info('Saving bind password failed (filename=%s ; exception=%s)', fn, e.__class__)
                 self.finished(request.id, {'success': False, 'message': _('Saving bind password failed (filename=%(fn)s ; exception=%(exception)s)') % {'fn': fn, 'exception': str(e.__class__)}})
                 return
 
-        ssldir = '/etc/univention/ssl/%s' % request.options.get('LDAP_Host')
+        ssldir = '/etc/univention/ssl/{}'.format(request.options.get('LDAP_Host'))
         if not os.path.exists(ssldir):
             self._create_certificate(request)
             return
 
         # enter a static host entry such that the AD server's FQDN can be resolved
-        univention.config_registry.handler_set(['hosts/static/%(Host_IP)s=%(LDAP_Host)s' % request.options])
+        univention.config_registry.handler_set(['hosts/static/{Host_IP}={LDAP_Host}'.format(**request.options)])
 
         # check for SSL support on AD side
         if admember.server_supports_ssl(server=request.options.get('LDAP_Host')):
             MODULE.process('Enabling SSL...')
             admember.enable_ssl()
         else:
-            MODULE.warn('SSL is not supported')
+            MODULE.warning('SSL is not supported')
             admember.disable_ssl()
 
         # UCR variables are set, and now we can try to guess the language of
         # the AD domain
         ad_lang = guess_ad_domain_language()
-        univention.config_registry.handler_set(['connector/ad/mapping/group/language=%s' % ad_lang])
+        univention.config_registry.handler_set([f'connector/ad/mapping/group/language={ad_lang}'])
 
         self.finished(request.id, {'success': True, 'message': _('Active Directory connection settings have been saved.')})
 
     def _create_certificate(self, request):
-        ssldir = '/etc/univention/ssl/%s' % request.options.get('LDAP_Host')
+        ssldir = '/etc/univention/ssl/{}'.format(request.options.get('LDAP_Host'))
 
         def _return(request, status):
             if not os.path.exists(ssldir):
-                MODULE.error('Creation of certificate failed (%s)' % ssldir)
+                MODULE.error('Creation of certificate failed (%s)', ssldir)
                 self.finished(request.id, {'success': False, 'message': _('Creation of certificate failed (%s)') % ssldir})
             self.finished(request.id, {'success': True, 'message': _('Active Directory connection settings have been saved and a new certificate for the Active Directory server has been created.')})
 
         cmd = ['/usr/sbin/univention-certificate', 'new', '-name', request.options['LDAP_Host']]
-        MODULE.info('Creating new SSL certificate: %s' % cmd)
+        MODULE.info('Creating new SSL certificate: %s', cmd)
         proc = tornado.process.Subprocess(cmd, stdout=subprocess.PIPE)
         proc.set_exit_callback(functools.partial(_return, request))
 
@@ -292,7 +264,7 @@ class Instance(Base, ProgressMixin):
             success = True
             if status == 0:
                 message = _('Certificate has been uploaded successfully.')
-                MODULE.info('Certificate has been uploaded successfully. status=%s\nSTDOUT:\n%s' % (status, bufstdout))
+                MODULE.info('Certificate has been uploaded successfully. status=%s\nSTDOUT:\n%s', status, bufstdout)
                 try:
                     self._enable_ssl_and_test_connection(fn)
                 except UMC_Error:
@@ -301,16 +273,16 @@ class Instance(Base, ProgressMixin):
             else:
                 success = False
                 message = _('Certificate upload or conversion failed.')
-                MODULE.process('Certificate upload or conversion failed. status=%s\nSTDOUT:\n%s' % (status, bufstdout))
+                MODULE.process('Certificate upload or conversion failed. status=%s\nSTDOUT:\n%s', status, bufstdout)
 
             self.finished(request.id, [{'success': success, 'message': message}])
 
         upload = request.options[0]['tmpfile']
         now = time.strftime('%Y%m%d_%H%M%S', time.localtime())
-        fn = '/etc/univention/connector/ad/ad_cert_%s.pem' % now
+        fn = f'/etc/univention/connector/ad/ad_cert_{now}.pem'
         cmd = ['/usr/bin/openssl', 'x509', '-inform', 'der', '-outform', 'pem', '-in', upload, '-out', fn]
 
-        MODULE.info('Converting certificate into correct format: %s' % cmd)
+        MODULE.info('Converting certificate into correct format: %s', cmd)
         proc = tornado.process.Subprocess(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         proc.set_exit_callback(functools.partial(_return, proc.stdout, request, fn))
 
@@ -321,7 +293,7 @@ class Instance(Base, ProgressMixin):
     def service(self, action):
         self.__update_status()
 
-        MODULE.info('State: action=%s  status_running=%s' % (action, self.status_running))
+        MODULE.info('State: action=%s  status_running=%s', action, self.status_running)
 
         message = None
         if self.status_running and action == 'start':
@@ -337,7 +309,7 @@ class Instance(Base, ProgressMixin):
             success = not result
             if result:
                 message = _('Switching running state of Active Directory Connector failed.')
-                MODULE.info('Switching running state of Active Directory Connector failed. exitcode=%s' % (result,))
+                MODULE.info('Switching running state of Active Directory Connector failed. exitcode=%s', result)
             else:
                 if action == 'start':
                     message = _('Active Directory connection service has been started.')
@@ -389,19 +361,19 @@ class Instance(Base, ProgressMixin):
             admember.check_connection(ad_domain_info, username, password)
             admember.check_ad_account(ad_domain_info, username, password)
         except admember.invalidUCSServerRole as exc:  # check_server_role()
-            MODULE.warn('Failure: %s' % exc)
+            MODULE.warning('Failure: %s', exc)
             raise UMC_Error(_('The AD member mode can only be configured on a Primary Directory Node.'))
         except admember.failedADConnect as exc:  # lookup_adds_dc()
-            MODULE.warn('Failure: %s' % exc)
-            raise UMC_Error(_('Could not connect to AD Server %s. Please verify that the specified address is correct. (%s)') % (ad_server_address, 'check_domain: %s' % (exc,)))
+            MODULE.warning('Failure: %s', exc)
+            raise UMC_Error(_('Could not connect to AD Server %s. Please verify that the specified address is correct. (%s)') % (ad_server_address, f'check_domain: {exc}'))
         except admember.domainnameMismatch as exc:  # check_domain()
-            MODULE.warn('Failure: %s' % exc)
+            MODULE.warning('Failure: %s', exc)
             raise UMC_Error(_('The domain name of the AD Server (%(ad_domain)s) does not match the local UCS domain name (%(ucs_domain)s). For the AD member mode, it is necessary to setup a UCS system with the same domain name as the AD Server.') % {'ad_domain': ad_domain_info.get("Domain"), 'ucs_domain': ucr['domainname']})
         except admember.connectionFailed as exc:  # check_connection()
-            MODULE.warn('Failure: %s' % exc)
+            MODULE.warning('Failure: %s', exc)
             raise UMC_Error(_('Could not connect to AD Server %s. Please verify that username and password are correct. (Details:\n%s)') % (ad_domain_info.get('DC DNS Name'), exc))
         except admember.notDomainAdminInAD as exc:  # check_ad_account()
-            MODULE.warn('Failure: %s' % exc)
+            MODULE.warning('Failure: %s', exc)
             raise UMC_Error(_('The given user is not member of the Domain Admins group in Active Directory. This is a requirement for the Active Directory domain join.'))
 
         # final info dict that is returned... replace spaces in the keys with '_'
@@ -438,7 +410,7 @@ class Instance(Base, ProgressMixin):
             if exc is not None:
                 exc_str = str(exc) or exc.__doc__  # if no message, take the doc string
                 exc_class_name = exc.__class__.__name__
-                MODULE.error('Join process failed [%s]: %s' % (exc_class_name, exc_str))
+                MODULE.error('Join process failed [%s]: %s', exc_class_name, exc_str)
 
             if msg:
                 MODULE.error(msg)
@@ -478,11 +450,11 @@ class Instance(Base, ProgressMixin):
             _nsteps = 35.0
 
             def _step_handler(step):
-                MODULE.process('Package manager progress: %.1f' % step)
+                MODULE.process('Package manager progress: %.1f', step)
                 progress.current = (step / 100.0) * _nsteps + _step_offset
 
             def _err_handler(err):
-                MODULE.warn(err)
+                MODULE.warning(err)
                 progress.warnings.append(err)
 
             success = admember.remove_install_univention_samba(info_handler=MODULE.process, error_handler=_err_handler, step_handler=_step_handler)
@@ -522,7 +494,7 @@ class Instance(Base, ProgressMixin):
         except admember.invalidUCSServerRole as exc:
             _err(exc, _('The AD member mode can only be configured on a Primary Directory Node.'))
         except admember.failedADConnect as exc:
-            _err(exc, _('Could not connect to AD Server %s. Please verify that the specified address is correct. (%s)') % (ad_domain_info.get('DC DNS Name'), 'admember_join: %s' % (exc,)))
+            _err(exc, _('Could not connect to AD Server %s. Please verify that the specified address is correct. (%s)') % (ad_domain_info.get('DC DNS Name'), f'admember_join: {exc}'))
         except admember.domainnameMismatch as exc:
             _err(exc, _('The domain name of the AD Server (%(ad_domain)s) does not match the local UCS domain name (%(ucs_domain)s). For the AD member mode, it is necessary to setup a UCS system with the same domain name as the AD Server.') % {'ad_domain': ad_domain_info["Domain"], 'ucs_domain': ucr['domainname']})
         except admember.connectionFailed as exc:
@@ -544,7 +516,7 @@ class Instance(Base, ProgressMixin):
         except Exception as exc:
             # catch all other errors that are unlikely to occur
             _err(exc)
-            MODULE.error('Traceback:\n%s' % traceback.format_exc())
+            MODULE.exception('Traceback')
 
         if not overall_success:
             _progress(100, _('Join has been finished with errors.'))
@@ -560,7 +532,7 @@ class Instance(Base, ProgressMixin):
     def _enable_ssl_and_test_connection(self, certificate_fname=None):
         with ucr_rollback(ucr, ['connector/ad/ldap/ssl', 'connector/ad/ldap/certificate']):
             if certificate_fname:
-                univention.config_registry.handler_set(['connector/ad/ldap/certificate=%s' % certificate_fname])
+                univention.config_registry.handler_set([f'connector/ad/ldap/certificate={certificate_fname}'])
             server = ucr.get('connector/ad/ldap/host')
             if server:
                 success = False
@@ -573,7 +545,7 @@ class Instance(Base, ProgressMixin):
                 if not success:
                     raise UMC_Error(_('Could not establish an encrypted connection. Either "%r" is not reachable or does not support encryption.') % server)
             else:
-                MODULE.warn('connector is not configured yet, cannot test connection')
+                MODULE.warning('connector is not configured yet, cannot test connection')
 
     @simple_response
     def enable_ssl(self):
@@ -585,7 +557,7 @@ class Instance(Base, ProgressMixin):
         # kinit=true  -> do not sync passwords, but use Kerberos authentication
         # kinit=false -> sync passwords
         value = str(not enable).lower()
-        univention.config_registry.handler_set(['connector/ad/mapping/user/password/kinit=%s' % value])
+        univention.config_registry.handler_set([f'connector/ad/mapping/user/password/kinit={value}'])
         return subprocess.call(['service', 'univention-ad-connector', 'restart'])
 
     @simple_response
